Properly closes the DuckDB database connection and shuts down the database driver.
Arguments
- conn
A DBI connection object from
db_init().
Properly closes the DuckDB database connection and shuts down the database driver.
A DBI connection object from db_init().