Performs a left join of classroom panel data with budget panel
data, using school_year and classroom_code as join keys. Budget-only
columns are appended to the classroom data (shared columns use classroom
as the authoritative source).
Performs a left join of classroom panel data with budget panel
data, using school_year and classroom_code as join keys. Budget-only
columns are appended to the classroom data (shared columns use classroom
as the authoritative source).