Performs a left join of student panel data with classroom panel
data, using school_year and classroom_code as join keys. Classroom-only
columns are appended to the student data (shared columns use student
as the authoritative source).
Performs a left join of student panel data with classroom panel
data, using school_year and classroom_code as join keys. Classroom-only
columns are appended to the student data (shared columns use student
as the authoritative source).